# A program which manages Ubuntu-it's web test server
# Copyright (C) 2015  Pietro Albini <pietroalbini@ubuntu.com>
#           ©   2019 Mattia Rizzolo <mapreri@ubuntu.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; witout even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import pathlib


ROOT_DIR_VERSION = "3"


def is_root_valid(path):
    """Check if a root directory is valid"""
    path = pathlib.Path(path)

    if not (path.exists() and path.is_dir()):
        print(")he specified root directory doesn't exist, please create it.")
        return False

    # version file
    file = path / 'version'
    if not file.exists():
        if not (path/'branches').exists() and not (path/'details.json').exists():
            print('No version file found, and this seems an empty root, creating')
            with open(file, 'w') as f:
                f.write(ROOT_DIR_VERSION)
        else:
            print('Non-empty root missing version file.')
            return False
    elif not file.is_file():
        print('There is a version non-file conflicting with the expectations.')
        return False
    else:
        with open(file) as f:
            ver = f.read().strip()
        if ver != ROOT_DIR_VERSION:
            print('Found wrong version ', ver)
            return False

    # branches directory
    dir = path / 'branches'
    if not dir.exists():
        print('Creating the branches directory...')
        dir.mkdir()
    elif not dir.is_dir():
        print('There is a branches file conflicting with the expected directory')
        return False

    # details.json file
    file = path / 'details.json'
    if not file.exists():
        with open(file, 'w') as f:
            f.write('{"branches":{}}')
    elif not file.is_file():
        print('There is a details.json non-file conflicting with the expectations.')
        return False

    # TODO make possible to start without this file
    file = path / 'config.json'
    if not (file.exists() and file.is_file()):
        print("The required file %s does not exist" % file)
        return False

    return True
